@@ -9,13 +9,14 @@ from types import SimpleNamespace
 ENCODING = sys.getdefaultencoding()
 
 
-def buffered_hook_manager(header_template, get_pos, cond_refresh, term):
+def buffered_hook_manager(header_template, get_pos, offset, cond_refresh, term):
     """Create and maintain a buffered hook manager, used for instrumenting print
     statements and logging.
 
     Args:
         header_template (): the template for enriching output
         get_pos (Callable[..., Any]): the container to retrieve the current position
+        offset (int): the offset to add to the current position
         cond_refresh: Condition object to force a refresh when printing
         term: the current terminal
 
@@ -51,23 +52,25 @@ def buffered_hook_manager(header_template, get_pos, cond_refresh, term):
                 part = part[:osc] + part[end + s:]
                 if not part:
                     return
-            # this will generate a sequence of lines interspersed with None, which will later
-            # be rendered as the indent filler to align additional lines under the same header.
-            gen = chain.from_iterable(zip(repeat(None), part.splitlines(True)))
-            buffer.extend(islice(gen, 1, None))
+            with cond_refresh:
+                # this will generate a sequence of lines interspersed with None, which will later
+                # be rendered as the indent filler to align additional lines under the same header.
+                gen = chain.from_iterable(zip(repeat(None), part.split('\n')))
+                buffer.extend(islice(gen, 1, None))
         else:
-            header = get_header()
-            spacer = ' ' * len(header)
-            nested = ''.join(line or spacer for line in buffer)
-            text = f'{header}{nested.rstrip()}\n'
             with cond_refresh:
                 if stream in base:  # pragma: no cover
                     term.clear_line()
                     term.clear_end_screen()
-                stream.write(text)
+                if buffer:
+                    header = get_header()
+                    spacer = '\n' + ' ' * len(header)
+                    nested = ''.join(spacer if line is None else line for line in buffer)
+                    buffer[:] = []
+                    stream.write(f'{header}{nested.rstrip()}')
+                stream.write('\n')
                 stream.flush()
                 cond_refresh.notify()
-                buffer[:] = []
 
     # better hook impl, which works even when nested, since __hash__ will be forwarded.
     class Hook(BaseHook):
@@ -119,7 +122,7 @@ def buffered_hook_manager(header_template, get_pos, cond_refresh, term):
 
     # internal data.
     buffers = defaultdict(list)
-    get_header = gen_header(header_template, get_pos) if header_template else null_header
+    get_header = gen_header(header_template, get_pos, offset)
     base = sys.stdout, sys.stderr  # needed for tests.
     before_handlers = {}
 
@@ -152,12 +155,11 @@ def __noop():  # pragma: no cover
     pass
 
 
-def gen_header(header_template, get_pos):  # pragma: no cover
-    def inner():
-        return header_template.format(get_pos())
+def gen_header(header_template, get_pos, offset):  # pragma: no cover
+    def header():
+        return header_template.format(get_pos() + offset)
 
-    return inner
+    def null_header():
+        return ''
 
-
-def null_header():  # pragma: no cover
-    return ''
+    return header if header_template else null_header
